@@ -11,4 +11,7 @@ class PubmedInterventionResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     pubmed_id = fields.Integer(required=True)
     intervention_id = fields.Integer(required=True)
+    score = fields.Float(required=True)
+    preferred = fields.Boolean(allow_none=True)
+    data_readout = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
